from math import cos, pi
import numpy as np
import scipy.signal as signal


HFT144D = [1.00000000, -1.96760033, 1.57983607, -0.81123644, 0.22583558, -0.02773848, 0.00090360]



def _calc_cosine_window (N, coeffs):
    a = (np.arange(N) + 0.5) * 2 * pi / N
    window = np.zeros ([N], float)
    for i in range (len (coeffs)):
        window += coeffs[i] * np.cos (i * a)
    return window


def get_window (name, size):
    if name == 'HFT144D':
        return _calc_cosine_window (size, HFT144D)
    else:
        return signal.get_window (name, size)


def tukey (v, size):
    if len(v) < 2*size:
        raise ValueError ("Tukey size too big for array")
    tuk = 0.5 * (1.0 - np.cos (pi * np.arange(size) / size))
    v[0:size] *= tuk
    v[-size:] *= tuk[::-1]

    
